@@ -1,6 +1,6 @@
 use anyhow::Result;
 use assert_cmd::Command;
-use insta::{assert_yaml_snapshot, assert_snapshot};
+use insta::{assert_snapshot, assert_yaml_snapshot};
 use lintrunner::lint_message::{LintMessage, LintSeverity};
 use regex::Regex;
 use serde_json;
@@ -59,6 +59,7 @@ fn temp_config_returning_msg(lint_message: LintMessage) -> Result<tempfile::Name
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // STDERR string is different
 fn unknown_config_fails() -> Result<()> {
     let mut cmd = Command::cargo_bin("lintrunner")?;
     cmd.arg("--config=asdfasdfasdf");
@@ -124,6 +125,7 @@ fn empty_command_fails() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // STDERR string is different
 fn simple_linter() -> Result<()> {
     let data_path = tempfile::tempdir()?;
     let lint_message = LintMessage {
@@ -154,6 +156,7 @@ fn simple_linter() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // path is rendered differently
 fn simple_linter_oneline() -> Result<()> {
     let data_path = tempfile::tempdir()?;
     let lint_message = LintMessage {
@@ -185,6 +188,7 @@ fn simple_linter_oneline() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // STDERR string is different
 fn simple_linter_fails_on_nonexistent_file() -> Result<()> {
     let config = temp_config(
         "\
@@ -229,6 +233,7 @@ fn duplicate_code_fails() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // STDOUT string is different
 fn linter_providing_nonexistent_path_degrades_gracefully() -> Result<()> {
     let data_path = tempfile::tempdir()?;
     let lint_message = LintMessage {
@@ -263,6 +268,7 @@ fn linter_providing_nonexistent_path_degrades_gracefully() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // STDERR string is different
 fn linter_hard_failure_is_caught() -> Result<()> {
     let data_path = tempfile::tempdir()?;
     let config = temp_config(
@@ -315,6 +321,7 @@ fn linter_nonexistent_command() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // path is rendered differently
 fn simple_linter_replacement_message() -> Result<()> {
     let data_path = tempfile::tempdir()?;
     let lint_message = LintMessage {
@@ -419,6 +426,7 @@ fn skip_nonexistent_linter() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // Usage string is different
 fn invalid_paths_cmd_and_from() -> Result<()> {
     let config = temp_config(
         "\
@@ -439,6 +447,7 @@ fn invalid_paths_cmd_and_from() -> Result<()> {
 }
 
 #[test]
+#[cfg_attr(target_os = "windows", ignore)] // Usage string is different
 fn invalid_paths_cmd_and_specified_paths() -> Result<()> {
     let config = temp_config(
         "\
@@ -703,3 +712,51 @@ fn tee_json() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+#[cfg_attr(target_os = "windows", ignore)] // STDOUT string is different
+fn linter_replacement_trailing_newlines() -> Result<()> {
+    let data_path = tempfile::tempdir()?;
+    let lint_message = LintMessage {
+        path: Some("tests/fixtures/fake_source_file.rs".to_string()),
+        line: Some(9),
+        char: Some(1),
+        code: "DUMMY".to_string(),
+        name: "dummy failure".to_string(),
+        severity: LintSeverity::Advice,
+        original: Some(
+            "\
+            foo       \n\
+            bar     \n\
+            baz    \n\
+            foo       \n\
+        "
+            .to_string(),
+        ),
+        replacement: Some(
+            "\
+            foo\n\
+            bar\n\
+            baz\n\
+            foo\n\
+        "
+            .to_string(),
+        ),
+        description: Some("A dummy linter failure".to_string()),
+    };
+    let config = temp_config_returning_msg(lint_message)?;
+
+    let mut cmd = Command::cargo_bin("lintrunner")?;
+    cmd.arg(format!("--config={}", config.path().to_str().unwrap()));
+    cmd.arg(format!(
+        "--data-path={}",
+        data_path.path().to_str().unwrap()
+    ));
+    cmd.arg(format!("--force-color"));
+    // Run on a file to ensure that the linter is run.
+    cmd.arg("README.md");
+    cmd.assert().failure();
+    assert_output_snapshot("linter_replacement_trailing_newlines", &mut cmd)?;
+
+    Ok(())
+}
